==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/util/annotated/AnnotatedParameterWrapper.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.util.annotated;

import java.lang.annotation.Annotation;
import java.util.Set;

import javax.enterprise.inject.spi.AnnotatedParameter;

public class AnnotatedParameterWrapper<X> extends AnnotatedWrapper implements AnnotatedParameter<X> {
    private AnnotatedParameter<X> delegate;
    private AnnotatedCallableWraper<X> declaringMethod;

    public AnnotatedParameterWrapper(AnnotatedParameter<X> delegate,  AnnotatedCallableWraper<X> declaringMethod, boolean keepOriginalAnnotations, Annotation... annotations) {
        super(delegate, keepOriginalAnnotations, annotations);
        this.declaringMethod = declaringMethod;
        this.delegate = delegate;

    }
    public AnnotatedCallableWraper<X> getDeclaringCallable(){
        return declaringMethod;
    }


    public int getPosition() {
        return delegate.getPosition();
    }

    @Override
    public <T extends Annotation> Set<T> getAnnotations(Class<T> annotationType) {
        return delegate.getAnnotations(annotationType);
    }

}

==> cdi-tck-3.0.1-dist.zip: org/jboss/cdi/tck/util/annotated/AnnotatedParameterWrapper.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.util.annotated;

import java.lang.annotation.Annotation;
import java.util.Set;

import jakarta.enterprise.inject.spi.AnnotatedParameter;

public class AnnotatedParameterWrapper<X> extends AnnotatedWrapper implements AnnotatedParameter<X> {
    private AnnotatedParameter<X> delegate;
    private AnnotatedCallableWraper<X> declaringMethod;

    public AnnotatedParameterWrapper(AnnotatedParameter<X> delegate,  AnnotatedCallableWraper<X> declaringMethod, boolean keepOriginalAnnotations, Annotation... annotations) {
        super(delegate, keepOriginalAnnotations, annotations);
        this.declaringMethod = declaringMethod;
        this.delegate = delegate;

    }
    public AnnotatedCallableWraper<X> getDeclaringCallable(){
        return declaringMethod;
    }


    public int getPosition() {
        return delegate.getPosition();
    }

    @Override
    public <T extends Annotation> Set<T> getAnnotations(Class<T> annotationType) {
        return delegate.getAnnotations(annotationType);
    }

}
